import os

__title__ = "botbuilder-sangam-dialogs-prompt"
__version__ = (
    os.environ["packageVersion"] if "packageVersion" in os.environ else "0.4.0"
)
__uri__ = "https://github.com/rvinothrajendran"
__author__ = "Bot Builder sangam"
__author_email__ = "r.vinoth@live.com"
__description__ = "Microsoft Bot Builder sangam dialogs prompts"
__summary__ = "A components is use for custom prompts to Microsoft Bot Builder SDK for Python"
__license__ = "MIT"
